<?php
/*
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}
include(_PS_MODULE_DIR_.'/centralpay/conf.inc.php');
class Centralpay extends PaymentModule
{
    protected $_html = '';
    protected $_postErrors = array();

    public $details;
    public $owner;
    public $address;
    public $extra_mail_vars;

    const _CENTRALPAY_ = '_CENTRALPAY_';

    public function __construct()
    {
        $this->name = 'centralpay';
        $this->tab = 'payments_gateways';
        $this->version = '1.1';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->author = 'CentralPay';
        $this->controllers = array('validation');
        $this->is_eu_compatible = 1;

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $this->bootstrap = true;
        /* curl check */
        if (is_callable('curl_init') === false) {
            $this->warning = $this->l('To be able to use this module, please activate cURL (PHP extension).');
        }

        parent::__construct();
        $this->meta_title = $this->l('CentralPay');
        $this->displayName = $this->l('CentralPay payment module V 2.0');
        $this->description = $this->l('Start accepting CentralPay payments today, directly from your shop!');

        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = $this->l('No currency has been set for this module.');
        }
    }

    public function install()
    {
        return parent::install()
            && $this->registerHook('payment')
            && $this->registerHook('paymentreturn')
            && $this->registerHook('customerAccount')
            && $this->registerHook('mycards')
            && $this->registerHook('header')
            && $this->registerHook('paymentOptions')
            && $this->registerHook('paymentReturn')
            //  && Configuration::updateValue(self::_CENTRALPAY_ . 'URL', 'https://test-api.centralpay.net/v2/rest/  ')
            //  && Configuration::updateValue(self::_CENTRALPAY_ . 'URL_JS', 'https://test-js.centralpay.net/js/token.js')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'LOGIN', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'PASSWORD', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . '3DS', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'FORCE3DS', '')
          && Configuration::updateValue(self::_CENTRALPAY_ . 'FORCECVC', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'POINTOFSALEID', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTCOUNTRY', '')
          && Configuration::updateValue(self::_CENTRALPAY_ . 'PROVIDER', '')
            && $this->createCentralpayTable();


      /*  if (!parent::install() || !$this->registerHook('paymentOptions') || !$this->registerHook('paymentReturn')) {
            return false;
        }
        return true;*/
    }

    public function uninstall()
    {
        Db::getInstance()->Execute('DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'centralpay_payment_card`');
        Db::getInstance()->Execute('DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'centralpay_card`');
        Db::getInstance()->Execute('DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'centralpay_customer`');
        return
            parent::uninstall()
            //  && Configuration::updateValue(self::_CENTRALPAY_ . 'URL', '')
            //  && Configuration::updateValue(self::_CENTRALPAY_ . 'URL_JS', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'LOGIN', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'PASSWORD', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . '3DS', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'FORCE3DS', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'FORCECVC', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'POINTOFSALEID', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTCOUNTRY', '')
            && Configuration::updateValue(self::_CENTRALPAY_ . 'PROVIDER', '')
            && Configuration::deleteByName('MYMODULE_NAME');
    }

    protected function createCentralpayTable()
    {
        $db = Db::getInstance();
        $query = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'centralpay_customer` (
          `customerId` VARCHAR(255) NOT NULL,
          `cmsCustomerId` VARCHAR(255) NOT NULL,
          `creationDate` DATETIME NOT NULL,
          PRIMARY KEY (`customerId`))
        ENGINE = ' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8';
        $db->Execute($query);

        $query2 = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'centralpay_card` (
                  `cardId` VARCHAR(255) NOT NULL,
                  `customerId` VARCHAR(255) NOT NULL,
                  `commercialBrand` VARCHAR(45) NULL,
                  `first6` VARCHAR(6) NULL,
                  `last4` VARCHAR(4) NULL,
                  `default` TINYINT(1) NULL,
                  `creationDate` DATETIME NULL,
                  `cardTokenId` VARCHAR(255) NULL,
                  `deleted` TINYINT(1) NULL,
                  `expirationYear` INT NULL,
                  `expirationMonth` INT NULL,
                  PRIMARY KEY (`cardId`),
                  INDEX `fk_centralpay_card_centralpay_customer_idx` (`customerId` ASC),
                  CONSTRAINT `fk_centralpay_card_centralpay_customer`
                    FOREIGN KEY (`customerId`)
                    REFERENCES `' . _DB_PREFIX_ . 'centralpay_customer` (`customerId`)
                    ON DELETE NO ACTION
                    ON UPDATE NO ACTION)
                ENGINE = ' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8';


        $db->Execute($query2);

        $db = Db::getInstance();
        $query3 = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'centralpay_payment_card` (
          `cardId` VARCHAR(255) NOT NULL,
          `cmsPaymentId` VARCHAR(255) NULL,
          INDEX `fk_centralpay_payment_card_centralpay_card1_idx` (`cardId` ASC),
          CONSTRAINT `fk_centralpay_payment_card_centralpay_card1`
            FOREIGN KEY (`cardId`)
            REFERENCES `' . _DB_PREFIX_ . 'centralpay_card` (`cardId`)
            ON DELETE NO ACTION
            ON UPDATE NO ACTION)
        ENGINE = ' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8';
        $db->Execute($query3);

        return true;
    }

    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('submit' . $this->name)) {


            //   $url = Tools::getValue(self::_CENTRALPAY_ . 'URL');
            //   $url_js = Tools::getValue(self::_CENTRALPAY_ . 'URL_JS');
            $mode_test = Tools::getValue(self::_CENTRALPAY_ . 'MODE_TEST');
            $ip = Tools::getValue(self::_CENTRALPAY_ . 'IP');
            $login = Tools::getValue(self::_CENTRALPAY_ . 'LOGIN');
            $password = Tools::getValue(self::_CENTRALPAY_ . 'PASSWORD');
            $troisds = Tools::getValue(self::_CENTRALPAY_ . '3DS');
            $forcetroisds = Tools::getValue(self::_CENTRALPAY_ . 'FORCE3DS');
          $forcecvc = Tools::getValue(self::_CENTRALPAY_ . 'FORCECVC');
            $publickey = Tools::getValue(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY');
            $merchantcountry = Tools::getValue(self::_CENTRALPAY_ . 'MERCHANTCOUNTRY');
            $point = Tools::getValue(self::_CENTRALPAY_ . 'POINTOFSALEID');
          $provider = Tools::getValue(self::_CENTRALPAY_ . 'PROVIDER');
            if ( empty($login) || empty($password) || empty($publickey) || empty($point))
                $output .= $this->displayError($this->l('Invalid Configuration value'));
            else {
                //  Configuration::updateValue(self::_CENTRALPAY_ . 'URL', $url);
                //  Configuration::updateValue(self::_CENTRALPAY_ . 'URL_JS', $url_js);
                Configuration::updateValue(self::_CENTRALPAY_ . 'LOGIN', $login);
                Configuration::updateValue(self::_CENTRALPAY_ . 'MODE_TEST', $mode_test);
                Configuration::updateValue(self::_CENTRALPAY_ . 'IP', $ip);
                Configuration::updateValue(self::_CENTRALPAY_ . 'PASSWORD', $password);
                Configuration::updateValue(self::_CENTRALPAY_ . '3DS', $troisds);
                Configuration::updateValue(self::_CENTRALPAY_ . 'FORCE3DS', $forcetroisds);
              Configuration::updateValue(self::_CENTRALPAY_ . 'FORCECVC', $forcecvc);
                Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY', $publickey);
                Configuration::updateValue(self::_CENTRALPAY_ . 'MERCHANTCOUNTRY', $merchantcountry);
                Configuration::updateValue(self::_CENTRALPAY_ . 'POINTOFSALEID', $point);
              Configuration::updateValue(self::_CENTRALPAY_ . 'PROVIDER', $provider);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }
        return $output . $this->displayForm();
    }

    public function displayForm()
    {
        // Get default language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        $options = array(
            array(
                'id_option' => 1,                 // The value of the 'value' attribute of the <option> tag.
                'name' => 'Oui'              // The value of the text content of the  <option> tag.
            ),
            array(
                'id_option' => 0,
                'name' => 'Non'
            ),
        );

      $options_provider = array(
        array(
          'id_option' => 'EMAIL',                 // The value of the 'value' attribute of the <option> tag.
          'name' => 'Email'              // The value of the text content of the  <option> tag.
        ),
        array(
          'id_option' => 'SMS',
          'name' => 'SMS'
        ),
        array(
          'id_option' => 'EMAIL_THEN_SMS',
          'name' => 'Email then SMS'
        ),
        array(
          'id_option' => 'SMS_THEN_SMS',
          'name' => 'SMS then Email'
        ),
      );

        // Init Fields form array
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Settings'),
            ),
            'input' => array(
                array(
                    'type' => 'select',
                    'label' => $this->l('Test mode'),
                    'name' => self::_CENTRALPAY_ . 'MODE_TEST',
                    'options' => array(
                        'query' => $options,                           // $options contains the data itself.
                        'id' => 'id_option',                           // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                        'name' => 'name'                               // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                    )

                ), array(
                    'type' => 'text',
                    'label' => $this->l('IP test mode'),
                    'name' => self::_CENTRALPAY_ . 'IP',
                    'size' => 20
                )/*, array(
                    'type' => 'text',
                    'label' => $this->l('API CPAY url'),
                    'name' => self::_CENTRALPAY_ . 'URL',
                    'size' => 20,
                    'required' => true
                ), array(
                    'type' => 'text',
                    'label' => $this->l('API CPAY JS url'),
                    'name' => self::_CENTRALPAY_ . 'URL_JS',
                    'size' => 20,
                    'required' => true
                )*/, array(
                    'type' => 'text',
                    'label' => $this->l('Login'),
                    'name' => self::_CENTRALPAY_ . 'LOGIN',
                    'size' => 20,
                    'required' => true
                ), array(
                    'type' => 'text',
                    'label' => $this->l('Password'),
                    'name' => self::_CENTRALPAY_ . 'PASSWORD',
                    'size' => 20,
                    'required' => true
                ), array(
                    'type' => 'text',
                    'label' => $this->l('Public key publique'),
                    'name' => self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY',
                    'size' => 20,
                    'required' => true
                ), array(
                    'type' => 'text',
                    'label' => $this->l('Code ISO Merchant country'),
                    'name' => self::_CENTRALPAY_ . 'MERCHANTCOUNTRY',
                    'size' => 20,
                    'required' => true
                ),array(
                    'type' => 'select',
                    'label' => $this->l('3DS'),
                    'name' => self::_CENTRALPAY_ . '3DS',
                    'options' => array(
                        'query' => $options,                           // $options contains the data itself.
                        'id' => 'id_option',                           // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                        'name' => 'name'                               // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                    )

                ), array(
                    'type' => 'select',
                    'label' => $this->l('Force 3DS'),
                    'name' => self::_CENTRALPAY_ . 'FORCE3DS',
                    'options' => array(
                        'query' => $options,                           // $options contains the data itself.
                        'id' => 'id_option',                           // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                        'name' => 'name'                               // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                    )

                ),array(
                'type' => 'select',
                'label' => $this->l('Force CVC'),
                'name' => self::_CENTRALPAY_ . 'FORCECVC',
                'options' => array(
                  'query' => $options,                           // $options contains the data itself.
                  'id' => 'id_option',                           // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                  'name' => 'name'                               // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                )

              ), array(
                    'type' => 'text',
                    'label' => $this->l('Point of sale'),
                    'name' => self::_CENTRALPAY_ . 'POINTOFSALEID',
                    'size' => 20,
                    'required' => true
                ),array(
                'type' => 'select',
                'label' => $this->l('Provider'),
                'name' => self::_CENTRALPAY_ . 'PROVIDER',
                'options' => array(
                  'query' => $options_provider,                           // $options contains the data itself.
                  'id' => 'id_option',                           // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                  'name' => 'name'                               // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                )
              )
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            )
        );

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit' . $this->name;
        $helper->toolbar_btn = array(
            'save' =>
                array(
                    'desc' => $this->l('Save'),
                    'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
                        '&token=' . Tools::getAdminTokenLite('AdminModules'),
                ),
            'back' => array(
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );

        // Load current value
        //  $helper->fields_value[self::_CENTRALPAY_ . 'URL'] = Configuration::get(self::_CENTRALPAY_ . 'URL');
        // $helper->fields_value[self::_CENTRALPAY_ . 'URL_JS'] = Configuration::get(self::_CENTRALPAY_ . 'URL_JS');
        $helper->fields_value[self::_CENTRALPAY_ . 'MODE_TEST'] = Configuration::get(self::_CENTRALPAY_ . 'MODE_TEST');
        $helper->fields_value[self::_CENTRALPAY_ . 'IP'] = Configuration::get(self::_CENTRALPAY_ . 'IP');
        $helper->fields_value[self::_CENTRALPAY_ . 'LOGIN'] = Configuration::get(self::_CENTRALPAY_ . 'LOGIN');
        $helper->fields_value[self::_CENTRALPAY_ . 'PASSWORD'] = Configuration::get(self::_CENTRALPAY_ . 'PASSWORD');
        $helper->fields_value[self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY'] = Configuration::get(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY');
        $helper->fields_value[self::_CENTRALPAY_ . 'MERCHANTCOUNTRY'] = Configuration::get(self::_CENTRALPAY_ . 'MERCHANTCOUNTRY');
        $helper->fields_value[self::_CENTRALPAY_ . '3DS'] = Configuration::get(self::_CENTRALPAY_ . '3DS');
        $helper->fields_value[self::_CENTRALPAY_ . 'FORCE3DS'] = Configuration::get(self::_CENTRALPAY_ . 'FORCE3DS');
      $helper->fields_value[self::_CENTRALPAY_ . 'FORCECVC'] = Configuration::get(self::_CENTRALPAY_ . 'FORCECVC');
        $helper->fields_value[self::_CENTRALPAY_ . 'POINTOFSALEID'] = Configuration::get(self::_CENTRALPAY_ . 'POINTOFSALEID');
      $helper->fields_value[self::_CENTRALPAY_ . 'PROVIDER'] = Configuration::get(self::_CENTRALPAY_ . 'PROVIDER');
        return $helper->generateForm($fields_form);
    }


    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }

        if (!$this->checkCurrency($params['cart'])) {
            return;
        }

        $payment_options = [

            $this->getEmbeddedPaymentOption(),

        ];

        return $payment_options;
    }

    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function hookcustomerAccount()
    {


        $this->context->smarty->assign(array(
            'HOOK_CUSTOMER_ACCOUNT' => '1'));
        return $this->display(__FILE__, 'my-account.tpl');
        // return '<li>ssssssssssssssssssss</li>';
    }



    public function getEmbeddedPaymentOption()
    {

            $embeddedOption = new PaymentOption();
        $embeddedOption->setCallToActionText($this->l('Pay by credit/debit card '))
            ->setForm($this->generateFormPayment())
            ->setAdditionalInformation($this->context->smarty->fetch('module:centralpay/views/templates/front/payment_infos.tpl'))
            ->setModuleName('module-centralpay');
            //->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/payment.jpg'));

        return $embeddedOption;
    }



    protected function generateFormPayment()
    {


        $months = [];
        for ($i = 1; $i <= 12; $i++) {
            $months[] = sprintf("%02d", $i);
        }

        $years = [];
        for ($i = 0; $i <= 10; $i++) {
            $years[] = date('Y', strtotime('+'.$i.' years'));
        }

        $this->context->smarty->assign([
            'action' => $this->context->link->getModuleLink($this->name, 'validation', array(), true),
            'months' => $months,
            'years' => $years,
        ]);


        global $smarty, $cart, $cookie,$customer;
        $ps_version15 = 0;
        if (version_compare(_PS_VERSION_, '1.6', '<')) {
            $ps_version15 = 1;
        }
        $amount = $cart->getOrderTotal();

        $currency = $this->context->currency->iso_code;


        $amount = $amount * 100;
        $address_delivery = new Address($this->context->cart->id_address_delivery);

        $billing_address = array(
            'line1' => $address_delivery->address1,
            'line2' => $address_delivery->address2,
            'city' => $address_delivery->city,
            'zip_code' => $address_delivery->postcode,
            'country' => $address_delivery->country,
        );


        //récupération des cartes de l'utilisateur en cours
        $hasCard = false;
        $id = (int)$this->context->cookie->id_customer;
        $cards = array();
        if ($id > 0) {
            $db = Db::getInstance();
            $sql = 'SELECT * FROM ' . _DB_PREFIX_ . 'centralpay_card as A INNER JOIN ' . _DB_PREFIX_ . 'centralpay_customer as B  ON A.customerId=B.customerId  WHERE A.deleted is NULL AND B.cmsCustomerId=' . intval($id) . ' ORDER BY A.default DESC,A.expirationYear DESC,A.expirationMonth DESC';
            $cards = Db::getInstance()->ExecuteS($sql);
            if (count($cards) > 0) {
                $hasCard = true;
            }
        }

        $id_lang = $cookie->id_lang;
        $lang = new Language($id_lang);

        if(Configuration::get(self::_CENTRALPAY_ . 'MODE_TEST')==1){
            $url_api=API_TEST;
            $url_js=JS_TEST;
        }else{
            $url_api=API;
            $url_js=JS;
        }

        $this->context->smarty->assign(
            array(
                'MerchantPublicKey' => Configuration::get(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY'),
                'currencyCard' => 'EUR',
                'amount' => $amount,
                'hasCard' => $hasCard,
                'idCard' => $cart->id,
                'cards' => $cards,
                'lastname' => $customer->lastname,
                'language' => strtoupper($lang->iso_code),
                'email' => $customer->email,
                'mode_test' => Configuration::get(self::_CENTRALPAY_ . 'MODE_TEST'),
                '3ds' => Configuration::get(self::_CENTRALPAY_ . '3DS'),
              'forcecvc' => Configuration::get(self::_CENTRALPAY_ . 'FORCECVC'),
                'firstname' => $customer->firstname,
                'url_cpay' => $url_api,
                'url_js_cpay' => $url_js,

            )
        );
        $html = '';
        /*return 'xxxxxxxxxxxxxxxxxx';
        if (version_compare(_PS_VERSION_, '1.6', '<')) {
            $html .= $this->context->smarty->fetch('module:centralpay/views/templates/hook/payment.tpl');
        }else{
           // $html .=  $this->context->smarty->fetch('module:centralpay/views/templates/front/payment_form.tpl');

            return $this->context->smarty->fetch('module:centralpay/views/templates/front/payment_form.tpl');
        }*/

        return $this->context->smarty->fetch('module:centralpay/views/templates/front/payment_form.tpl');

      //  return $html;


        //return $this->context->smarty->fetch('module:paymentexample/views/templates/front/payment_form.tpl');
    }

    public function hookHeader($params)
    {

        if(Configuration::get(self::_CENTRALPAY_ . 'MODE_TEST')==1){
            $url_js=JS_TEST;
        }else{
            $url_js=JS;
        }

        Media::addJsDef(array('MerchantPublicKey' => Configuration::get(self::_CENTRALPAY_ . 'MERCHANTPUBLICKEY')));
        $this->context->controller->addCSS($this->_path . 'css/font-awesome.css');
        $this->context->controller->addCSS($this->_path . 'css/centralpay.css');
        $this->context->controller->registerJavascript(
            'jquery',
            '//ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js',
            ['server' => 'remote', 'position' => 'head', 'priority' => 30]
        );
        $this->context->controller->registerJavascript(
            'centralpay',
            $this->_path . $url_js,
            ['server' => 'remote', 'position' => 'head', 'priority' => 20]
        );

     //   $this->context->controller->addJS($url_js);

        $this->context->controller->addJS($this->_path . 'js/validator.min.js');
        $this->context->controller->addJS($this->_path . 'js/jquery.inputmask.bundle.js');
        $this->context->controller->addJS($this->_path . 'js/jquery.payment.min.js');
        $this->context->controller->addJS($this->_path . 'js/jquery.qtip.min.js');
        $this->context->controller->addJS($this->_path . 'js/centralpay.js');

    }
}
